NicheRange

Struct NicheRange 

pub struct NicheRange {
    pub offset: u32,
    pub width: u8,
    pub start: u128,
    pub end: u128,
}
A forbidden bit-pattern range within a value of some type.

Reading the width bytes at offset (interpreted as a little-endian unsigned integer) from any valid value will never yield a value in [start, end] (inclusive). Surrounding contexts (e.g. an enclosing enum) can reuse those bit patterns to encode tag information.

Fields

offset: u32

Byte offset within the type where the niche-bearing bytes live.

width: u8

Width of the niche-bearing region, in bytes.

start: u128

Inclusive start of the forbidden range.

end: u128

Inclusive end of the forbidden range.

Implementations

Source

impl NicheRange

pub fn count(&self) -> u128

Number of forbidden bit patterns in this niche.

pub fn max_for_width(width: u8) -> u128

Maximum value representable in width bytes (inclusive).