pub struct NicheRange {
pub offset: u32,
pub width: u8,
pub start: u128,
pub end: u128,
}Expand description
A forbidden bit-pattern range within a value of some type.
Reading the width bytes at offset (interpreted as a little-endian
unsigned integer) from any valid value will never yield a value in
[start, end] (inclusive). Surrounding contexts (e.g. an enclosing enum)
can reuse those bit patterns to encode tag information.
Fields
offset: u32Byte offset within the type where the niche-bearing bytes live.
width: u8Width of the niche-bearing region, in bytes.
start: u128Inclusive start of the forbidden range.
end: u128Inclusive end of the forbidden range.
Implementations
Sourceimpl NicheRange
impl NicheRange